module.exports = defineTest({
	description: 'supports arbitrary module namespace identifiers'
});
